@@ -2,14 +2,16 @@
 //!
 //!
 //! See https://tc39.github.io/ecma262/#sec-literals-numeric-literals
-use super::*;
-use crate::error::SyntaxError;
+use std::fmt::Write;
+
 use either::Either;
 use num_bigint::BigInt as BigIntValue;
-use std::fmt::Write;
 use swc_common::SyntaxContext;
 use tracing::trace;
 
+use super::*;
+use crate::error::SyntaxError;
+
 impl<'a, I: Input> Lexer<'a, I> {
     /// Reads an integer, octal integer, or floating-point number
     pub(super) fn read_number(
@@ -425,9 +427,10 @@ impl<'a, I: Input> Lexer<'a, I> {
 
 #[cfg(test)]
 mod tests {
+    use std::{f64::INFINITY, panic};
+
     use super::{input::StringInput, *};
     use crate::EsConfig;
-    use std::{f64::INFINITY, panic};
 
     fn lex<F, Ret>(s: &'static str, f: F) -> Ret
     where
@@ -566,7 +569,7 @@ mod tests {
     #[test]
     fn read_num_sep() {
         assert_eq!(1_000, int(10, "1_000"));
-        assert_eq!(0xAEBECE, int(16, "AE_BE_CE"));
+        assert_eq!(0xaebece, int(16, "AE_BE_CE"));
         assert_eq!(0b1010000110000101, int(2, "1010_0001_1000_0101"));
         assert_eq!(0o0666, int(8, "0_6_6_6"));
     }
