@@ -298,7 +298,7 @@ pub(super) trait ExprExt {
             Expr::TsNonNull(TsNonNullExpr { ref expr, .. })
             | Expr::TsTypeAssertion(TsTypeAssertion { ref expr, .. })
             | Expr::TsAs(TsAsExpr { ref expr, .. })
-            | Expr::TsInstantiation(TsExprWithTypeArgs { ref expr, .. }) => {
+            | Expr::TsInstantiation(TsInstantiation { ref expr, .. }) => {
                 expr.is_valid_simple_assignment_target(strict)
             }
 
